@@ -4,6 +4,8 @@ from enum import Enum
 import json
 from typing import Any, List, Dict, Union
 
+from kameleoon.helpers.string_utils import StringUtils
+
 
 class Variable:
     """
@@ -39,3 +41,12 @@ class Variable:
         if self.__type == Variable.Type.JSON.value and isinstance(self.__value, str):
             return json.loads(self.__value)
         return None
+
+    def get_type(self) -> str:
+        """Returns type value of variable"""
+        return self.__type
+
+    def __str__(self):
+        return (f"Variable{{key:'{self.key},"
+                f"type:'{self.__type}',"
+                f"value:{StringUtils.object_to_string(self.__value)}}}")
