@@ -4,6 +4,7 @@ from enum import Enum
 from typing import Any, List, Dict, Optional
 
 from kameleoon.configuration.variable import Variable
+from kameleoon.helpers.string_utils import StringUtils
 
 
 class Variation:
@@ -29,3 +30,7 @@ class Variation:
     def get_variable_by_key(self, key: str) -> Optional[Variable]:
         """Retrun a variable for the given key"""
         return next((v for v in self.variables if v.key == key), None)
+
+    def __str__(self):
+        return (f"Variation{{key:'{self.key}',"
+                f"variables:{StringUtils.object_to_string(self.variables)}}}")
