@@ -51,10 +51,16 @@ class Browser(Data, DuplicationUnsafeSendableBase):
     def data_type(self) -> DataType:
         return DataType.BROWSER
 
-    def _add_query_params(self, qb: QueryBuilder) -> None:
-        qb.extend(
+    def _add_query_params(self, query_builder: QueryBuilder) -> None:
+        query_builder.extend(
             QueryParam(QueryParams.EVENT_TYPE, self.EVENT_TYPE),
             QueryParam(QueryParams.BROWSER_INDEX, str(self.browser_type.value)),
         )
         if self.version:
-            qb.append(QueryParam(QueryParams.BROWSER_VERSION, str(self.version)))
+            query_builder.append(QueryParam(QueryParams.BROWSER_VERSION, str(self.version)))
+
+    def __str__(self):
+        return (
+            f"Browser{{browser_type:{self.__browser_type},"
+            f"version:{self.__version}}}"
+        )
