@@ -51,12 +51,19 @@ class Conversion(Data, DuplicationSafeSendableBase):
     def data_type(self) -> DataType:
         return DataType.CONVERSION
 
-    def _add_query_params(self, qb: QueryBuilder) -> None:
+    def _add_query_params(self, query_builder: QueryBuilder) -> None:
         # remove query_builder, it's done due due pylint issue with R0801 - duplicate_code,
         # need to update pylint and return str(QueryBuilder) straightaway
-        qb.extend(
+        query_builder.extend(
             QueryParam(QueryParams.EVENT_TYPE, self.EVENT_TYPE),
             QueryParam(QueryParams.GOAL_ID, str(self.goal_id)),
             QueryParam(QueryParams.REVENUE, str(self.revenue)),
             QueryParam(QueryParams.NEGATIVE, "true" if self.negative else "false"),
         )
+
+    def __str__(self):
+        return (
+            f"Conversion{{goal_id:{self.__goal_id},"
+            f"revenue:{self.__revenue},"
+            f"negative:{self.__negative}}}"
+        )
