@@ -2,8 +2,9 @@
 
 from typing import Optional, Tuple
 
+from kameleoon.logging.kameleoon_logger import KameleoonLogger
 
-version_info = (3, 3, 3)
+version_info = (3, 4, 0)
 __version__ = ".".join(str(v) for v in version_info)  # uses in scripts
 
 
@@ -23,7 +24,7 @@ class SdkVersion:
             try:
                 versions[i] = int(version_parts[i])
             except ValueError:
-                print(f"Invalid version component, index: {i}, value: {version_parts[i]}")
+                KameleoonLogger.error("Invalid version component, index: %s, value: %s", i, version_parts[i])
                 return None
 
         return (versions[0], versions[1], versions[2])
