@@ -1,6 +1,7 @@
 """Conversion condition"""
 from typing import Any, Dict, List, Union
 from kameleoon.data import Conversion
+from kameleoon.logging.kameleoon_logger import KameleoonLogger
 from kameleoon.targeting.conditions.targeting_condition import TargetingCondition
 
 
@@ -12,7 +13,7 @@ class ConversionCondition(TargetingCondition):
         try:
             self.__goal_id = json_condition.get("goalId", TargetingCondition.NON_EXISTENT_IDENTIFIER)
         except KeyError as ex:
-            self._logger.error("%s has wrong JSON structure: %s", self.__class__, ex)
+            KameleoonLogger.error("%s has wrong JSON structure: %s", self.__class__, ex)
 
     def check(self, data: Any) -> bool:
         return isinstance(data, list) and self.__check(data)
