@@ -1,13 +1,15 @@
 """Variable"""
 from typing import Any, Optional
 
+from kameleoon.helpers.string_utils import StringUtils
+
 
 class Variable:
     """Variable"""
 
-    def __init__(self, key: str, type: str, value: Optional[Any]):
+    def __init__(self, key: str, type_: str, value: Optional[Any]):
         self.__key = key
-        self.__type = type
+        self.__type = type_
         self.__value = value
 
     @property
@@ -24,3 +26,8 @@ class Variable:
     def value(self) -> Optional[Any]:
         """Return value"""
         return self.__value
+
+    def __str__(self):
+        return (f"Variable{{key:'{self.__key}',"
+                f"type:'{self.__type}',"
+                f"value:{StringUtils.object_to_string(self.__value)}}}")
