@@ -10,7 +10,7 @@ ROOT_DIR = os.path.join(
 sys.path.append(ROOT_DIR)
 
 from tests_defaults import SITE_CODE
-from kameleoon import KameleoonClient
+from kameleoon import KameleoonClient, KameleoonClientConfig
 
 from tests.test_network_manager_factory import TestNetworkManagerFactory
 
@@ -20,8 +20,8 @@ class KameleoonConfig(AppConfig):
     name = "kameleoon_app"
 
     def ready(self):
-        configuration_path = os.path.join(ROOT_DIR, "tests", "resources", "config.yml")
+        config_path = os.path.join(ROOT_DIR, "tests", "resources", "config.yml")
+        config = KameleoonClientConfig.read_from_yaml(config_path)
         KameleoonClient._network_manager_factory = TestNetworkManagerFactory()
-        self.kameleoon_client = KameleoonClient(
-            SITE_CODE, configuration_path=configuration_path
-        )
+        self.kameleoon_client = KameleoonClient(SITE_CODE, config)
+        self.kameleoon_client.wait_init()
